%alternative transition matrix routine using error funcions
%here each z_p implies an equally spaced vector of z_1
function TMR3 = TMR3alt(x)
global N mu_A sigma_A NA


%it solves for the grid points and bin endpoints given the input
%parameters for Z, z_p, z_1,

%Parents' skills and assets assumed jointly log-normal
%(log A, log z_P) ~ N((mu_A, mu_P), [sigma_A^2, rho_zPA sigma_A sigma_zP;   rho_zPA sigma_A sigma_zP, sigma_zP^2])

%Process for kids' first period's skills
%log z_1 = rho_zG (log z_P - mu_zP) + e_zG + mu_z1
%e_G ~ N(0, sigma_zG^2)
%note: log z_1 ~ N(mu_z1, rho_zG^2*sigma_zP^2 + sigma_zG^2)
%note: log z_1|log z_P ~ N(rho_zG*(log z_P - mu_zP) + mu_z1, sigma_zG^2)


%Process for kids' second period's skills
%log z_2 = rho_L (log z_1 - mu_z1) + e_zL + mu_z2
%e_L ~ N(0, sigma_zL^2)
%note: log z_2 ~ N(mu_z2, rho_zL^2*(rho_zG^2* sigma_zP^2 + sigma_zG^2) + sigma_zL^2)
%note: log z_2|log z_1 ~ N(rho_zL*(log z_1 - mu_1) + mu_z2, sigma_zL^2)

%Define values of parameters (could make it a function with these inputs later)
mu_zP    = x(1);
rho_zPA  = x(2);
mu_z1    = x(3);
sigma_zG = x(4);
rho_zG   = x(5);
mu_z2    = x(6); 
sigma_zL = x(7);
rho_zL   = x(8);

%just use the equations and SS assumption
%sigma_zP = ((rho_zL^2*sigma_zG^2 + sigma_zL^2)/(1-rho_zG^2*rho_zL^2))^.5;
sigma_zP = 0.78;
%load sigma_zP
%sigma_zP
%sigma_zL = .6
%sigma_zP = 1.2007
%sigma_z1 = ((rho_zG^2*sigma_zL^2 + sigma_zG^2)/(1-rho_zG^2*rho_zL^2))^.5;
%sigma_z2 = sigma_zP;

%Define the number of grid points
n = N;

%gridpoints and bins on log z_P
grid_P = erfinv(2*( 1/(2*n):1/n:1-1/(2*n))-1)*2^.5*sigma_zP+ mu_zP; %this is s.d.
bin_P = erfinv(2*( 1/n:1/n:1)-1)*2^.5*sigma_zP+ mu_zP;


%gridpoints and bins on log z_1
grid_1 = erfinv(2*( kron(1/(2*n):1/n:1-1/(2*n),ones(n,1)))-1)*2^.5.*(sigma_zG*ones(n,n))+ kron(mu_z1 + rho_zG*(grid_P' - mu_zP),ones(1,n));
bin_1 = erfinv(2*( kron(1/n:1/n:1,ones(n,1)))-1)*2^.5.*(sigma_zG*ones(n,n))+ kron(mu_z1 + rho_zG*(grid_P' - mu_zP),ones(1,n));

%bins and grid points for A - unconditional (marginal) distribution
grid_A = erfinv(2*((1/(2*NA):1/NA:1-1/(2*NA)))-1)*2^.5.*(sigma_A)+ mu_A;
bin_A = erfinv(2*((1/NA:1/NA:1))-1)*2^.5.*(sigma_A)+ mu_A;

%here I need to integrate
% initial probabilities for A, zP pairs

    k = 10000; %number of gridpoints for numerical integration, no change in results if 
    %we go from 1000 to 10000 can as well leave 10000, takes no time
    
    %create gridpoint for zP and z1 and A
    %grid_P2 = icdf('normal', 1/(2*k):1/k:1-1/(2*k), mu_zP, sigma_zP)';
    grid_A2 = (erfinv(2*(1/(2*k):1/k:1-1/(2*k))-1)*2^.5*sigma_A + mu_A)';
    
    %probabilities for each point on the big grid into the bins
    matrix = 1/2*(1+erf( (ones(k,1)*bin_P -  (mu_zP + (rho_zPA*sigma_zP/sigma_A)*(grid_A2 - mu_A)*ones(1,N)))./(2^.5*(sigma_zP^2*(1-rho_zPA^2))^.5)));
   
    PP = zeros(NA,N);

    
    for i = 1:NA
      PP(i,:) =  sum(matrix((i-1)*k/NA+1:k/NA*i,:))/(k);
    end
    %to get from cdf to probabilities
    PP(:, 2:n) = PP(:, 2:n) - PP(:, 1:n-1);
  
    
    %output - a matrix with n columns and in lines the data
    TMR3 = [grid_P; bin_P; grid_1; bin_1;  kron(grid_A',ones(1,N)); kron(bin_A', ones(1,N)); PP];    

