clear all;
%clc

%%%This version uses our estimated wage processes directly. It calibrates phi and eta (and beta).

%Structure if the codes:
%code_calib.m    - TMR3alt.m, TMR6alt.m (tauchen procedure to determine the shocks and distributions)
%                - wnew.m (continuation values)
%                - calibbeta.m or cali4.m (calibrates also the transfers by kids) --- systemnew.m (solves the FOC system)
%                - output2.m (computes 2nd period's allocations)
%                - IC.m (check the IC's)

%profile on


global Z1 A u up v vp W Wliefn W_b N T TG TL sigma gamma ZP Z1mat Z2mat grid_A R beta Z2 P PP mu_A sigma_A N2 NA N mu_yP policies data Pemp y_21 y_22 mures l phi1 phi2 k

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
R = 1.04^25;

NA = 5; %number of states for A
%then #states z_1 = N^2
N = NA; %number of states for z_p and each z_1|z_2
N2 = NA; %number os states for z_2|z_P

%log number of hours in 25 years: years*weeks per year*hours per week
loghours = log(25*52.1429*120);
mu_yP = 2.02+loghours-log(3);

%directly chosen
mu_A = 11.23;
sigma_A = 1.60;

%eta = 1; 
sigma = 1; 
gamma = 1;

bla = zeros(7,1);

%2016 versions
bla(1) =  .65;
bla(2) =  .47;
bla(6) =  .25;
bla(7) =  .76;

%calculated mean wages in terms of annual income
bla(3) =   2.02+loghours - mu_yP; %should be exp(3)
bla(5) =   2.45+loghours - mu_yP;
bla(4) =   0.65;

%2017 versions
bla(1) =  .88;
bla(2) =  .47;
bla(6) =  .25;
bla(7) =  .78;

bla(3) =   2.02+loghours - mu_yP; %should be exp(3)
bla(5) =   2.39+loghours - mu_yP;
bla(4) =   0.65;

%calculated mean wages (equivalized)
sigma_zL =  bla(1);
sigma_zG =  bla(2);
mu_zP =     bla(3);
rho_zPA =   bla(4);
mu_z1 =     bla(5);
rho_zG =    bla(6);
rho_zL =    bla(7);

%parameters = [sigma_zL; sigma_zG; mu_zP; rho_zPA; mu_z1; rho_zG; rho_zL];

%use appropriate guesses!!!
load Policies2017/policies1_1.mat
%load Policies2017/policies1_05.mat
%load Policies2017/policies1_1equalB.mat
%load Policies2017/policies1_1equalG.mat
%load Policies2017/policies1_1NoNeg.mat
%load Policies2017/policiesFBequal.mat 
%load Policies2017/policiesFB.mat

mu_z2 = 2.22 + loghours - mu_yP;
x = [mu_zP; rho_zPA; mu_z1; sigma_zG; rho_zG; mu_z2; sigma_zL; rho_zL];

trans1 = TMR3alt(x);
trans2 = TMR6alt(x);
 
 %transition matrices
 TG = ones(N,N)/N;
 TL = trans2(1:N^2, :);%by definition they have to be the same, so:
 T = TL(1:N, :);

 %grid for parents skills
 ZP = exp(trans1(1,:)');
  
 %grids for kids' skills in the first period
 Z1mat = exp(trans1(3:2+N,:));

 %grid for kids' skills in the second period
 Z2mat = exp(trans2(N^2+1:N^2+N,:));
 
 %grid for assets
 grid_A = exp(trans1(2*N+3: 2*N+2+NA,1)')/exp(mu_yP); %assets measured in 20 years average income, 

  %initial distribution on the parent's types
 PP = trans1(3+ 2*N + 2*NA: 3*NA+2*N+2,:)';

 %utility
if sigma == 1
   u  = @(c) log(c);
   up = @(c) 1./c;
else
    u  = @(c) c.^(1-sigma)./(1-sigma);
    up = @(c) c.^-sigma;
end

v  = @(l) l.^(1+gamma)./(1+gamma);
vp = @(l) l.^gamma;
     
%continuation values - gives out the whole vector of continuation
%values and behind it derivatives, seems better by ~15%
W   = @(b, t) sum([kron(t, ones(N,1));kron(t, ones(N,1))].*wnew(b),2);

%for the 'dynastic model'
 phi1 = 0; phi2 = 0;
 %phi1 = beta; phi2 = 1;
 
 %phi1 = beta;
 %phi2 = 4.2;
 %only works for equal gamma = sigma
 %W   = @(b, t) sum([kron(t, ones(N,1));kron(t, ones(N,1))].*wdyn(b),2);

Z11vector = zeros(N^4,1);
%bench for second best
eta = 0.989008594989609; phi = 6.79834759224759; beta = 0.276222217928078;

%bench for first best
%phi = 7.57508266470327; eta =1.09004318521491; beta = 0.269214206299106;

%bench for second best with sigma = 1, gamma = 0.5
%eta = 1.0350; phi = 3.8617; beta = 0.2735;

x0 = [phi, eta, beta];
%x0 = [phi, eta, beta, phi2];
%load x0 x0
%x0(4) = 1; 

tic;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%loop in phi to hit the l target
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
options = optimset('display', 'iter','tolfun', 10^(-10), 'tolX', 10^(-10), 'maxfunevals', 1000000,'maxiter', 20);%
%options = optimset('display', 'iter','tolfun', 10^(-10), 'tolX', 10^(-10), 'maxfunevals', 1000000,'maxiter', 1000000, 'NonlEqnAlgorithm', 'gn');%
         ynew = fsolve(@calibbeta,x0, options);  phi = ynew(1); eta = ynew(2); beta = ynew(3);
        %ynew = fsolve(@calibbetaFB, x0, options);  phi = ynew(1); eta = ynew(2); beta = ynew(3);
        %ynew = fsolve(@calib4, x0, options); phi = ynew(1); eta = ynew(2); beta = ynew(3); phi2 = ynew(4);
        
        %calib4(x0)
        %calibbeta(x0)
        %calibbetaFB(x0)
          
toc;

%save ('Policies2017/policies1_05.mat', 'policies')
%save ('Policies2017/policiesFB.mat', 'policies')
%save ('Policies2016/yprime1_1.mat', 'yprime')
%save ('Policies2016/cprime1_1.mat', 'cprime')

%save ('Policies2017/policies1_1equalB.mat', 'policies')
%save ('Policies2017/policies1_1equalG.mat', 'policies')
%save ('Policies2017/policiesFBequal.mat', 'policies')
%save ('Policies2017/policies1_1NoNeg.mat', 'policies')


x0 = ynew;
save x0 x0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%     MODEL IMPLIED DATA     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%compute some statistics from the model, without _, data have it

logy1 = mu_yP + log(data(:,7));
logy2 = mu_yP + log(data(:,8));%for the second kid, not period!
logyP = mu_yP + log(data(:,9));
yP = exp(logyP);


c1 = exp(mu_yP + log(data(:,4)));
c2 = exp(mu_yP + log(data(:,5)));

cP = exp(mu_yP + log(data(:,6)));
gP = cP - yP;
logA   = mu_yP + log(data(:,1));
meancP = cP'*Pemp;
meanyP = yP'*Pemp;
meanlogyP = logyP'*Pemp;

%within family differences in income
meandiflogy = abs(logy1-logy2)'*Pemp;
meanvarlogy = ((logy1 - (logy1 + logy2)/2).^2)'*Pemp;

%not logged
y1units = data(:,7)*exp(mu_yP);
meany1units = y1units'*Pemp;
y2units = data(:,8)*exp(mu_yP);
%within family differences in income
meandify = abs(y1units-y2units)'*Pemp;
meanvary = ((y1units - (y1units + y2units)/2).^2)'*Pemp;

%logged means and variances
muy1 = logy1'*Pemp;
vary1 = ((logy1' - muy1).^2)*Pemp;

muyP = logyP'*Pemp;
varyP = ((logyP' - muyP).^2)*Pemp;

muA = logA'*Pemp; %OK = mu_A
varA = ((logA' - muA).^2)*Pemp;

covyPA = ((logyP - muyP).*(logA - muA))'*Pemp;
corryPA = covyPA/(varyP^.5*varA^.5);

covyPy1 = (logyP.*logy1)'*Pemp - muyP*muy1;
rhoyG = covyPy1/varyP; %this is the regression coefficient from OLS

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%   second period junk   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%logged second period's allocations
y_21 = mu_yP + log(y_21);
y_22 = mu_yP + log(y_22);

%generate the probability matrix, seems the same as in code3.m
P2 = kron(Pemp, ones(1, N)).*(kron(ones(N*NA,1),kron(T, ones(N,1))));
meany_21 = sum(sum(P2.*y_21));
vary_21 = sum(sum(P2.*(y_21-meany_21).^2));

%expected income in period 2
ey_21 = sum(P2.*exp(y_21),2)./sum(P2,2);
%ey_22 = sum(P2.*exp(y_22),2)./sum(P2,2);%this looks wrong, should have different P2, because we take the second kid, not the first one now
meanyperiod2 = ey_21'*Pemp;

%matrix of first period's income for regression
y_11 = kron(logy1, ones(1,N));
cov12 = sum(sum((y_21 - meany_21).*(y_11 - muy1).*P2));
rhoyL = cov12/vary1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%         TRUE GIFTS        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%s1 = exp(- 4.6971 + 1.1489*logy1);
%s2 = exp(- 4.6971 + 1.1489*logy2);

s1 = exp(-9.8624 + 1.5460*logy1);
s2 = exp(-9.8624 + 1.5460*logy2);

%s1 = exp(-11.1936 + 1.6443*logy1);
%s2 = exp(-11.1936 + 1.6443*logy2);

g1units = data(:,10)*exp(mu_yP) + s1/R;
g2units = data(:,11)*exp(mu_yP) + s2/R;
gdif = g1units - g2units;

mug = (g1units + g2units)'/2*Pemp;
varg = ((g1units - mug).^2)'*Pemp;

%variables for the regression
error1 = random('normal', 0, 50000, [N^4,1]);
error2 = random('normal', 0, 50000, [N^4,1]);
greg = g1units - g2units  + error1 - error2;
meangreg = greg'*Pemp;

yreg = y1units - y2units;
meanyreg = yreg'*Pemp;
varyreg = ((yreg - meanyreg).^2)'*Pemp;
covgy = ((greg - meangreg).*(yreg - meanyreg))'*Pemp;
betagy = covgy/varyreg;

gAHK = gP - g1units;
meangAHK = gAHK'*Pemp;
yAHK = yP - y1units;
meanyAHK = yAHK'*Pemp;
varyAHK = ((yAHK - meanyAHK).^2)'*Pemp;
covAHK = ((gAHK- meangAHK).*(yAHK - meanyAHK))'*Pemp;
betaAHK = covAHK/varyAHK;

meang = g1units'*Pemp;
logmeang = ((meang>0)*2-1)*log(abs(meang));

meanabsg = abs(g1units)'*Pemp;
logmeanabsg = log(meanabsg);

%including diagonal guys
prob02g  = (abs(2*g1units./(g1units + g2units) - 1)<.02)'*Pemp;%probability that true bequests within 2% for those who are not the same
prob125g = (abs(2*g1units./(g1units + g2units) - 1)<.125)'*Pemp;
prob20g = (abs(2*g1units./(g1units + g2units) - 1)<.2)'*Pemp;
prob25g  = (abs(2*g1units./(g1units + g2units) - 1)<.25)'*Pemp;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%% "TRUE BEQUESTS" %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
beq1 = data(:,12)*exp(mu_yP); 
beq2 = data(:,13)*exp(mu_yP);

%s1 = exp(- 4.6971 + 1.1489*logy1);
%s2 = exp(- 4.6971 + 1.1489*logy2);

trueb1 = (beq1 - s1)/R;
trueb2 = (beq2 - s2)/R;
meantrueb = (trueb1 + trueb2)/2;

beqdif = trueb1-trueb2;

truelogb1 = log(trueb1);
truelogb2 = log(trueb2);

meanb = trueb1'*Pemp;
logmeanb = ((trueb1'*Pemp>0)*2-1)*log(abs(trueb1'*Pemp));
meanabsb = abs(trueb1)'*Pemp;
logmeanabsb = log(meanabsb);

%true bequests in levels
breg = trueb1 - trueb2;
%breg = trueb1;
meanbreg = breg'*Pemp;
covby = ((breg - meanbreg).*(yreg - meanyreg))'*Pemp;
betaby = covby/varyreg;

%including diagonal guys
prob02  = (abs(trueb1./meantrueb - 1)<.02)'*Pemp;%probability that true bequests within 2% for those who are not the same
prob125 = (abs(trueb1./meantrueb - 1)<.125)'*Pemp;
prob20 = (abs(trueb1./meantrueb - 1)<.2)'*Pemp;
prob25  = (abs(trueb1./meantrueb - 1)<.25)'*Pemp;

standard =(((trueb1 - trueb2).^2)'*Pemp)^.5;
%std(2*(trueb1)./(trueb1 + trueb2))

plot(y1units -y2units, trueb1-trueb2,'.')
axis([-6*10^5, 6*10^5, -6*10^5, 6*10^5 ])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
targets = [muyP; varyP; muy1; vary1; corryPA; rhoyG; rhoyL];
result =  [meanb/meany1units, betaby, mug/meany1units, betagy ,prob02, prob125, prob20, prob25, prob02g, prob125g, prob20g, prob25g, rhoyL]';
result2 = [standard; meancP; meanyP; exp(meanlogyP); (meanb+meang)/meanyP];

totr = (g1units + beq1/R + g2units + beq2/R)'*Pemp/exp(mu_yP);
totr = (g1units + beq1 + g2units + beq2)'*Pemp/exp(mu_yP);

[min(beqdif), max(beqdif)];
[min(gdif), max(gdif)];

mures = mures';
PP = reshape(PP,N^2,1);
min(trueb1);

%scatter = [y1units-y2units, trueb1-trueb2]/10^6;

finout = [result; result2;eta; bla; phi; l; targets; phi1; phi2; beta; R];
load V V
%profile off