*Please, use Stata 13.

clear all
set more off
set type double, permanently

*this file estimates the correlation between fathers' wage in ages 50-75 and sons' at the age 25-50
*whenever a year is missing it drops the observation

cd "c:\Users\cslavik\Research\AAA Optimal Contracting\Bequests\our paper\RED submsission\Codes and Data\PSID Data and Codes\"

use Data_panel_ID.dta, clear
*************************************************
* 1. tracked years and interviews
*************************************************
sort identifier year

* SRC sample
keep if ID<= 3000

generate ID68 = int(identifier/1000)
label variable ID68 "Identification number in the 1968 survey"
generate PN68 = identifier-ID68*1000
label variable PN68 "Person number in the 1968 s
drop ID

*focus on fathers and sons as in the literature
keep if SexHead == 1

*keeping track only of biological children right now
replace Head = 3 if Relation == 3 & year >= 1968 & year <= 1982
replace Head = 3 if Relation == 30 & year >= 1983

order identifier year ID68 PN68 AgeHead AgeWife Relation Head SexHead IW FatherPN MotherPN

xtset identifier year

keep if Head == 1

************************************************
* 1b. HPV sampling
* A. HPV procedure drop either the head or spouse has positive labor income but zero annual hours
************************************************
drop if HeadTotalWage>0 & HeadHours==0

*additional cleaning
drop if HeadTotalWage==0 & HeadHours>0

*drop if HeadTotalWage == . & HeadHours > 0
*will not be used anyways

drop if HeadWage_gen>0 & HeadWage_gen<0.1*MinWageNom

*some checking
order identifier year HeadWageHour HeadWage_gen  HeadHours HeadTotalWage HeadWage

*additional cleaning
replace HeadWage_gen=0 if HeadHours==0 & HeadTotalWage==0

*************************************************
* 2. real wages
* note that in the data I use interview year, which is reporting for last year's info
* I adjusted the year cpi by -1
*************************************************

gen HeadWageHourReal = HeadWage_gen/cpi*100
*gen WifeWageHourReal = WifeWageHour/cpi*10000

keep identifier year ID68 PN68 AgeHead FatherPN HeadWageHourReal

*extrapolating for missing years
xtset identifier year
expand 2 if year> 1997


sort identifier year
quietly by identifier year:  gen dup = cond(_N==1,0,_n)
replace year = year-1 if year> 1997 & dup==2
xtset identifier year
replace HeadWageHourReal = (l1.HeadWageHourReal + f1.HeadWageHourReal)/2 if year> 1997 & dup==2
*Age will be recalculated again later anyways
replace AgeHead = (l1.AgeHead + f1.AgeHead)/2 if year> 1997 & dup==2
drop if HeadWageHourReal ==. & year> 1997 & dup==2
drop dup


*gen issue = 1 if AgeHead == l1.AgeHead
bys identifier: egen age_min = min(AgeHead)
bys identifier: egen year_min = min(year)
gen age = age_min + year - year_min 

*I think of ages as 25.00 - 49.99 and 50.00 - 74.99
drop if age < 25
drop if age > 74

*************************************************
* 3. matching fathers and sons
*************************************************

expand 2
sort identifier year
quietly by identifier year:  gen dup = cond(_N==1,0,_n) 
tab dup
replace age = age-25 if dup == 2
replace PN68 = PN68+1000 if dup == 2

rename HeadWageHourReal wage
keep year ID68 PN68 FatherPN age wage
gen number = PN68

count
*this matches father and son so that fathers' income is 25 years later
reshape wide wage FatherPN number year, i(ID68 age) j(PN68)

save DataInter2reshaped.dta, replace
*Here reshaping to wide format done, so save it.

use DataInter2reshaped.dta, clear
*drop fatherwage*
#delimit ;
foreach tson of numlist 1 2 3 4 5 6 7 8 9 10 11 12 13 20 21 22 24 25 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 170 171 172 173
 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 
 204 205 206 207 208 209 210 211 212 214 215 216 217 218 219 220 222 223 224 226 227 229 230 231 232 233 234 236 237 240 
 243 244 245 246 248 250 252 261 264  {;
 quietly gen fatherwage`tson' = .;
 foreach tfat of numlist 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1020 1021 1022 1024 1025
 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1170 1171 1172 1173 1174 1175 
 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200
 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1214 1215 1216 1217 1218 1219 1220 1222 1223 1224 1226 1227
  1229 1230 1231 1232 1233 1234 1236 1237 1240 1243 1244 1245 1246 1248 1250 1252 1261 1264
 {; 
 quietly replace fatherwage`tson' = wage`tfat' if 1000+FatherPN`tson' == number`tfat' & FatherPN`tson' ~= . & `tfat'~= 1000+`tson';
 };
 *dropmiss fatherwage`tson', force;
 };
 
 #delimit cr

reshape long year wage fatherwage FatherPN number, i(ID68 age) j(PN68)
drop if number == . & wage == . & fatherwage == . & FatherPN == .

sort ID68 PN68 age
count

save DataInter2.dta, replace
*Here fathers and sons at different ages (50-75 fathers and 25-50 sons) are matched, so save it.

**************************************************************************************************

use DataInter2.dta, clear
 
*************************************************
* 4. wage correlations
*************************************************
gen identifier = ID68*1000000+PN68

xtset identifier age
drop if fatherwage == .

*approximate number of people
gen counting = identifier - l1.identifier
replace counting = 1 if counting ==.
replace counting = . if counting ==0

gen meanwage = wage
gen logmeanwage = log(wage)
gen meanfwage = fatherwage
gen logmeanfwage = log(fatherwage)
gen meanwageold = meanwage
gen meanfwageold = meanfwage

gen year2 = year^2
gen age2 = age^2

qui replace number = 1
*generate average wage of fathers and sons when
forvalues tt = 1(1)24 {
*display "Aggregation level " `tt'

qui replace meanfwageold = meanfwage*number
qui replace meanwageold = meanwage*number
qui replace number = number+1
qui replace meanwage = (meanwageold+f`tt'.wage)/number
qui replace logmeanwage = log(meanwage)
qui replace meanfwage = (meanfwageold+f`tt'.fatherwage)/number
qui replace logmeanfwage = log(meanfwage)
}
regress logmeanwage logmeanfwage
