*Please, use Stata 13.

clear all
set more off
set type double, permanently

*this file calculated transfers statistics, look in the file SRC_4table_results.xlsx fopr results.

cd "c:\Users\cslavik\Research\AAA Optimal Contracting\Bequests\our paper\RED submsission\Codes and Data\PSID Data and Codes\"

*************************************************
*************************************************
* Construct the final tables
*************************************************
*************************************************
use Data_panel_family.dta, clear

************************************************
* 1. HPV sampling
* A. HPV procedure drop either the head or spouse has positive labor income but zero annual hours
************************************************
drop if HeadTotalWage > 0 & HeadHours == 0
drop if HeadTotalWage == . & HeadHours > 0

* B. either the head or spouse has an hourly wage less than half of the corresponding federal minimum wage in that year
drop if HeadWageHour >0 & HeadWageHour < 0.1*MinWageNom
drop if WifeWageHour >0 & WifeWageHour < 0.1*MinWageNom

* C. is done in data_construction, just above block no. 4
************************************************
save Data_panel_family_HPV.dta, replace

******************************************
******************************************
******************************************
* SRC sample
*****************************************

use Data_panel_family_HPV.dta, clear

* gen DuplicateBequests = 1 if (HeadAgeBequest ~=. & WifeAgeBequest ~= .)
* too many missing variables for gifts, I replace them with zeros
keep if ID <= 3000
*gen GiftHH = RelativeHead + NonrelativeHead + RelativeWife + NonrelativeWife
gen GiftHH = RelativeHead + RelativeWife

drop NumHHYear
bys year: egen NumHHYear = count(_n)

bys year: egen AvgNumHH    = mean(NumHHYear)
bys year: egen AvgHeadWage = mean(HeadTotalWage)
bys year: egen AvgWifeWage = mean(WifeTotalWage)
bys year: egen AvgHHWage   = mean(HHWage)
bys year: egen AvgBequestHH  = mean(Transfer)
* average age of getting bequest is just for the head
bys year: egen AvgHeadAgeBequest  = mean(HeadAgeBequest)
bys year: egen MedHeadAgeBequest  = median(HeadAgeBequest)
bys year: egen AvgWifeAgeBequest  = mean(WifeAgeBequest)
bys year: egen MedWifeAgeBequest  = median(WifeAgeBequest)
bys year: egen AvgRelativeHead = mean(RelativeHead)
bys year: egen AvgRelativeWife = mean(RelativeWife)
bys year: egen AvgNonrelativeHead = mean(NonrelativeHead)
bys year: egen AvgNonrelativeWife = mean(NonrelativeWife)
bys year: egen AvgGiftHH = mean(GiftHH)
bys year: egen AvgHeadHours = mean(HeadHours)
bys year: egen AvgWifeHours = mean(WifeHours)
keep Avg* year Med*
duplicates drop year, force

export excel using "SRC_Average.xls", firstrow(variables) replace
saveold Data_Average.dta, replace
*************************************************
* Construct Excel Sheet for Average Year Data
* replace . with 0
*************************************************

use Data_panel_family_HPV.dta, clear
keep if ID <= 3000
replace HeadTotalWage = 0 if HeadTotalWage == .
replace WifeTotalWage = 0 if WifeTotalWage == .
replace RelativeHead    = 0 if RelativeHead == .
replace NonrelativeHead = 0 if NonrelativeHead == .
replace RelativeWife    = 0 if RelativeWife == .
replace NonrelativeWife = 0 if NonrelativeWife == .
replace Transfer        = 0 if Transfer == .
*gen GiftHH = RelativeHead + NonrelativeHead + RelativeWife + NonrelativeWife
gen GiftHH = RelativeHead + RelativeWife

drop NumHHYear
bys year: egen NumHHYear = count(_n)
bys year: egen AvgNumHH0    = mean(NumHHYear)
bys year: egen AvgHeadWage0  = mean(HeadTotalWage)
bys year: egen AvgWifeWage0  = mean(WifeTotalWage)
bys year: egen AvgHHWage0   = mean(HHWage)
bys year: egen AvgBequestHH0 = mean(Transfer)
bys year: egen AvgRelativeHead0 = mean(RelativeHead)
bys year: egen AvgRelativeWife0 = mean(RelativeWife)
bys year: egen AvgNonrelativeHead0 = mean(NonrelativeHead)
bys year: egen AvgNonrelativeWife0 = mean(NonrelativeWife)
bys year: egen AvgGiftHH0 = mean(GiftHH)
bys year: egen AvgHeadAgeBequest0  = mean(HeadAgeBequest)
bys year: egen AvgWifeAgeBequest0  = mean(WifeAgeBequest)
bys year: egen MedHeadAgeBequest0  = median(HeadAgeBequest)
bys year: egen MedWifeAgeBequest0  = median(WifeAgeBequest)
bys year: egen AvgHeadHours0 = mean(HeadHours)
bys year: egen AvgWifeHours0 = mean(WifeHours)
keep Avg* year Med*
duplicates drop year, force
save Data_Average0.dta, replace
export excel using "SRC_Average0.xls", firstrow(variables) replace

*********************************************
* sample for ones with positive bequests
use Data_panel_family_HPV.dta, clear
keep if ID <= 3000
keep if Transfer >0 & Transfer ~= .

replace RelativeHead    = 0 if RelativeHead == .
replace NonrelativeHead = 0 if NonrelativeHead == .
replace RelativeWife    = 0 if RelativeWife == .
replace NonrelativeWife = 0 if NonrelativeWife == .

*gen GiftHH = RelativeHead + NonrelativeHead + RelativeWife + NonrelativeWife
gen GiftHH = RelativeHead + RelativeWife
drop NumHHYear
bys year: egen NumHHYear = count(_n)
drop if year<1988
count
tab HeadAgeBequest

bys year: egen AvgNumHH1    = mean(NumHHYear)
bys year: egen AvgHeadWage1 = mean(HeadTotalWage)
bys year: egen AvgWifeWage1 = mean(WifeTotalWage)
bys year: egen AvgHHWage1   = mean(HHWage)
bys year: egen AvgBequestHH1  = mean(Transfer)
* average age of getting bequest is just for the head
bys year: egen AvgHeadAgeBequest1  = mean(HeadAgeBequest)
bys year: egen MedHeadAgeBequest1  = median(HeadAgeBequest)
bys year: egen AvgWifeAgeBequest1  = mean(WifeAgeBequest)
bys year: egen MedWifeAgeBequest1  = median(WifeAgeBequest)
bys year: egen AvgRelativeHead1 = mean(RelativeHead)
bys year: egen AvgRelativeWife1 = mean(RelativeWife)
bys year: egen AvgNonrelativeHead1 = mean(NonrelativeHead)
bys year: egen AvgNonrelativeWife1 = mean(NonrelativeWife)
bys year: egen AvgGiftHH1 = mean(GiftHH)
bys year: egen AvgHeadHours1 = mean(HeadHours)
bys year: egen AvgWifeHours1 = mean(WifeHours)
keep Avg* year Med*
duplicates drop year, force
save Data_nonzeroBequests.dta, replace
export excel using "SRC_nonzeroBequest.xls", firstrow(variables) replace

*********************************************
* sample for ones with positive relative gifts

use Data_panel_family_HPV.dta, clear
keep if ID <= 3000

replace RelativeHead    = 0 if RelativeHead == .
replace NonrelativeHead = 0 if NonrelativeHead == .
replace RelativeWife    = 0 if RelativeWife == .
replace NonrelativeWife = 0 if NonrelativeWife == .

*gen GiftHH = RelativeHead + NonrelativeHead + RelativeWife + NonrelativeWife
gen GiftHH = RelativeHead + RelativeWife
keep if GiftHH >0 & GiftHH ~= .

drop NumHHYear
bys year: egen NumHHYear = count(_n)

bys year: egen AvgNumHH2    = mean(NumHHYear)
bys year: egen AvgHeadWage2 = mean(HeadTotalWage)
bys year: egen AvgWifeWage2 = mean(WifeTotalWage)
bys year: egen AvgHHWage2  = mean(HHWage)
bys year: egen AvgBequestHH2  = mean(Transfer)
* average age of getting bequest is just for the head
bys year: egen AvgHeadAgeBequest2  = mean(HeadAgeBequest)
bys year: egen MedHeadAgeBequest2  = median(HeadAgeBequest)
bys year: egen AvgWifeAgeBequest2  = mean(WifeAgeBequest)
bys year: egen MedWifeAgeBequest2  = median(WifeAgeBequest)
bys year: egen AvgRelativeHead2 = mean(RelativeHead)
bys year: egen AvgRelativeWife2 = mean(RelativeWife)
bys year: egen AvgNonrelativeHead2 = mean(NonrelativeHead)
bys year: egen AvgNonrelativeWife2 = mean(NonrelativeWife)
bys year: egen AvgGiftHH2 = mean(GiftHH)
bys year: egen AvgHeadHours2 = mean(HeadHours)
bys year: egen AvgWifeHours2 = mean(WifeHours)
keep Avg* year Med*
duplicates drop year, force
save Data_nonzeroRelatives.dta, replace
export excel using "SRC_nonzeroRelatives.xls", firstrow(variables) replace

*********************************************
* sample for ones with the first bequests
use Data_panel_family_HPV.dta, clear
keep if ID <= 3000
keep if Transfer >0 & Transfer ~= .
keep if bequest_indicator == 1 & bequest_cum == 1

replace RelativeHead    = 0 if RelativeHead == .
replace NonrelativeHead = 0 if NonrelativeHead == .
replace RelativeWife    = 0 if RelativeWife == .
replace NonrelativeWife = 0 if NonrelativeWife == .

*gen GiftHH = RelativeHead + NonrelativeHead + RelativeWife + NonrelativeWife
gen GiftHH = RelativeHead + RelativeWife
drop NumHHYear
bys year: egen NumHHYear = count(_n)
bys year: egen AvgNumHH3    = mean(NumHHYear)
bys year: egen AvgHeadWage3 = mean(HeadTotalWage)
bys year: egen AvgWifeWage3 = mean(WifeTotalWage)
bys year: egen AvgHHWage3   = mean(HHWage)
bys year: egen AvgBequestHH3  = mean(Transfer)
* average age of getting bequest is just for the head
bys year: egen AvgHeadAgeBequest3  = mean(HeadAgeBequest)
bys year: egen MedHeadAgeBequest3  = median(HeadAgeBequest)
bys year: egen AvgWifeAgeBequest3  = mean(WifeAgeBequest)
bys year: egen MedWifeAgeBequest3  = median(WifeAgeBequest)
bys year: egen AvgRelativeHead3 = mean(RelativeHead)
bys year: egen AvgRelativeWife3 = mean(RelativeWife)
bys year: egen AvgNonrelativeHead3 = mean(NonrelativeHead)
bys year: egen AvgNonrelativeWife3 = mean(NonrelativeWife)
bys year: egen AvgGiftHH3 = mean(GiftHH)
bys year: egen AvgHeadHours3 = mean(HeadHours)
bys year: egen AvgWifeHours3 = mean(WifeHours)
keep Avg* year Med*
duplicates drop year, force
save Data_FirstBequests.dta, replace
export excel using "SRC_FirstBequests.xls", firstrow(variables) replace


******************************************
* Combine the four
*****************************************
use Data_Average0.dta, clear

merge 1:1 year  using Data_nonzeroBequests.dta
drop _merge
merge 1:1 year  using Data_nonzeroRelatives.dta
drop _merge
merge 1:1 year  using Data_FirstBequests.dta

label variable AvgHeadWage0 "Replace Missing with Zeros"
label variable AvgHeadWage1 "Positive Bequests"
label variable AvgHeadWage2 "Positive Relative Gifts"
label variable AvgHeadWage1 "First Bequests"
drop _merge

order *, alpha
order year
export excel using "SRC_4table.xls", firstrow(variables) replace




